<?php
/**
 * interico functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Interico
 */

/**
 * Define the version for js and css files
 */
define( 'INTERICO_VERSION', wp_get_theme()->get( 'Version' ) );

/* Hide ACF in admin menu */
// add_filter( 'acf/settings/show_admin', '__return_false' );

/* Load ACF fields */
require_once( get_template_directory() . '/inc/acf-fields.php' );

add_filter('site_transient_update_plugins', 'acf_remove_update_nag');
function acf_remove_update_nag($value) {
	if ( isset( $value ) && is_object( $value ) ) {
		unset($value->response[ 'advanced-custom-fields-pro/acf.php' ]);
		return $value;
	}
}

if ( ! function_exists( 'interico_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function interico_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 */
	load_theme_textdomain( 'interico', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Add WooCommerce support
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// Normal post thumbnails
	set_post_thumbnail_size( 1140, 580, true );

	// Blog widget image size
	add_image_size( 'interico-blog-s', 430, 220, true );
	add_image_size( 'interico-blog-l', 900, 450, true );

	// Testimonial
	add_image_size( 'interico-testimonial-s', 72, 72, true );

	// Project Featured image size
	add_image_size( 'interico-portfolio-xs', 240, 180, true );
	add_image_size( 'interico-portfolio-s', 360, 240, true );
	add_image_size( 'interico-portfolio-ml', 420, 280, true );
	add_image_size( 'interico-portfolio-m', 480, 320, true );
	add_image_size( 'interico-portfolio-l', 600, 400, true );
	add_image_size( 'interico-portfolio-xl', 780, 520, true );
	add_image_size( 'interico-portfolio-vertical-s', 480, 760, true );
	add_image_size( 'interico-portfolio-vertical-xs', 360, 570, true );
	add_image_size( 'interico-portfolio-vertical-xl', 600, 900, true );
	add_image_size( 'interico-portfolio-vertical-l', 600, 760, true );

	// Slider image size
	add_image_size( 'interico-slider-desktop', 1920, 780, true );

	// Service Item image size
	add_image_size( 'interico-service-s', 260, 180, true );
	add_image_size( 'interico-service-m', 360, 250, true );
	add_image_size( 'interico-service-l', 760, 540, true );
	add_image_size( 'interico-service-vertical-s', 270, 380, true );
	add_image_size( 'interico-service-vertical-m', 360, 500, true );
	add_image_size( 'interico-service-vertical-l', 540, 750, true );

	if ( false === get_option( 'thumbnail_crop' ) ) {
	add_option( 'thumbnail_crop', '1' );
	} else {
		update_option( 'thumbnail_crop', '1');
	}
	 
	// Medium Size Thumbnail Crop
	if( false === get_option( 'medium_crop' ) ) {
		add_option( 'medium_crop', '1' );
	} else {
		update_option( 'medium_crop', '1' );
	}

	// Enable shortcodes in text widgets
	add_filter( 'widget_text','do_shortcode' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'interico' ),
		'secondary' => esc_html__( 'Secondary', 'interico' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'interico_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// TinyMCE styles
	add_editor_style();
}
endif;
add_action( 'after_setup_theme', 'interico_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function interico_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'interico_content_width', 640 );
}
add_action( 'after_setup_theme', 'interico_content_width', 0 );

add_filter( 'wpcf7_load_js', '__return_false' );
add_filter( 'wpcf7_load_css', '__return_false' );

/**
 * Enqueue scripts and styles.
 */
function interico_scripts() {
	$url_prefix = is_ssl() ? 'https:' : 'http:';

	// CSS Files
	wp_enqueue_style( 'interico-fonts', interico_fonts_url(), array(), null );

    // Main CSS file
    wp_enqueue_style( 'interico-style', get_stylesheet_uri(), array(), INTERICO_VERSION, null );

    // Font Awesome font
    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/fonts/font-awesome/css/font-awesome.css' );
    
    // JavaScript files
	wp_enqueue_script( 'navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'isotope', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array(), false, true );
	wp_enqueue_script( 'imagesloaded', get_template_directory_uri() . '/js/imagesloaded.pkgd.min.js', null, true );
	wp_enqueue_script( 'slick', get_template_directory_uri() . '/js/slick.min.js', array( 'jquery' ), false, true );

	if ( is_rtl() ) {
		// Main JS file RTL
		wp_enqueue_script( 'interico-themicart-rtl', get_template_directory_uri() . '/js/themicart-rtl.js', array( 'jquery' ), false, true );
	} else {
		// Main JS file
		wp_enqueue_script( 'interico-themicart', get_template_directory_uri() . '/js/themicart.js', array( 'jquery' ), false, true );
	}
	if ( function_exists( 'wpcf7_enqueue_scripts' ) ) {
        wpcf7_enqueue_scripts();
    }
 
    if ( function_exists( 'wpcf7_enqueue_styles' ) ) {
        wpcf7_enqueue_styles();
    }
}
add_action( 'wp_enqueue_scripts', 'interico_scripts' );


function interico_add_init() {
	// Add admin styling
    wp_enqueue_style( 'interico-admin', get_template_directory_uri() .'/css/admin.css');
}

add_action( 'admin_print_styles', 'interico_add_init' );

/**
 * Register theme sidebars
 */
require_once( get_template_directory() . '/inc/theme-sidebars.php' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions to help build Interico styling and functionality.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Woocommerce customizations file.
 */
require get_template_directory() . '/inc/woocommerce.php';

/**
 * Load all Widgets.
 */

/* Widget: Feature Box */
require get_template_directory() . '/inc/widgets/widget-feature-box.php';

/* Widget: Projects Single Category */
require get_template_directory() . '/inc/widgets/widget-projects-single-category.php';

/* Widget: Projects Slider */
require get_template_directory() . '/inc/widgets/widget-projects-slider.php';

/* Widget: Projects */
require get_template_directory() . '/inc/widgets/widget-projects.php';

/* Widget: Blog posts */
require get_template_directory() . '/inc/widgets/widget-blog-posts.php';

/* Widget: Testimonials slider */
require get_template_directory() . '/inc/widgets/widget-testimonials.php';

/* Widget: Team member */
require get_template_directory() . '/inc/widgets/widget-team-member.php';

/* Widget: Single Testimonial box */
require get_template_directory() . '/inc/widgets/widget-testimonial-box.php';

/* Widget: Number box */
require get_template_directory() . '/inc/widgets/widget-number-box.php';

/* Widget: Image box */
require get_template_directory() . '/inc/widgets/widget-image-box.php';

/* Load WPBakery shortcodes */
if ( function_exists( 'vc_map' ) ) {
require	get_template_directory() . '/inc/wpb_shortcodes.php';
}

/*
 * Load admin area files: plugin activation, content import, auto updates.
 */
if ( is_admin() ) {
	/* TGM Plugin Activation */
	require_once( get_template_directory() . '/inc/class-tgm-plugin-activation.php' );
	require_once( get_template_directory() . '/inc/tgm-plugin-activation.php' );

	/* Import Demo Data */
	require_once( get_template_directory() . '/inc/demo-content-import.php' );
}