<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Interico
 */

?>

<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

	<?php wp_head(); ?>
</head>

<?php

$subnav_color  = get_theme_mod( 'tc_subnav_color_scheme', 'subnav-dark' );
$subnav_hide_mobile = get_theme_mod( 'tc_subnav_hide_mobile', 'yes' );

$tc_subnav_text_1 = get_theme_mod( 'tc_subnav_text_1', 'Opening time: Mon-Fri 08:00 - 18:00' );
$tc_subnav_text_2 = get_theme_mod( 'tc_subnav_text_2', 'Email: info@interico.com' );
$tc_subnav_text_3 = get_theme_mod( 'tc_subnav_text_3', 'Phone: +1 (378) 400-1234' );

?>

<body <?php body_class(); ?>>

	<div class="preloader-wrapper dark">
	    <div class="preloader"></div>
	</div>

	<div id="wrapper">

	<?php if ( 'no' !== get_theme_mod( 'tc_subnav', 'no' ) ) : ?>
		<!-- Begin Subheader -->
		<div class="subnav<?php echo 'subnav-light' === $subnav_color ? ' ' . 'subnav-light' : ''; echo 'yes' === $subnav_hide_mobile ? ' ' . 'hide-on-mobile' : ''; ?>">
			<div class="container">
				<div class="row">
					<div class="col-md-12">
						<div class="subnav-item">
							<p>
								<i class="fa <?php echo esc_attr( get_theme_mod( 'tc_subnav_icon_1', 'fa-clock-o' ) ); ?>" aria-hidden="true"></i>
								<?php printf( esc_html__( '%s', 'interico' ), $tc_subnav_text_1 ); ?>
							</p>
						</div>
						<div class="subnav-item">
							<p>
								<i class="fa <?php echo esc_attr( get_theme_mod( 'tc_subnav_icon_2', 'fa-envelope-o' ) ); ?>" aria-hidden="true"></i>
								<?php printf( esc_html__( '%s', 'interico' ), $tc_subnav_text_2 ); ?>
							</p>
						</div>
						<div class="subnav-item">
							<p>
								<i class="fa <?php echo esc_attr( get_theme_mod( 'tc_subnav_icon_3', 'fa-phone' ) ); ?>" aria-hidden="true"></i>
								<?php printf( esc_html__( '%s', 'interico' ), $tc_subnav_text_3 ); ?>
							</p>
						</div>

						<?php if ( has_nav_menu( 'secondary' ) ) : ?>
							<nav>
								<?php wp_nav_menu(
									array(
										'theme_location' => 'secondary',
										'menu_id'		 => 'nav-secondary', 
										'menu_class'	 => 'nav-secondary',
										)
									); ?>
							</nav>
						<?php endif; ?>

						<ul class="social">
							<?php if ( esc_url( get_theme_mod( 'tc_social_facebook', '#' ) ) ) : ?>
								<li><a target="_blank" href="<?php echo esc_url( get_theme_mod( 'tc_social_facebook', '#' ) ); ?>"><i class="fa fa-facebook" aria-hidden="true"></i></a></li>
							<?php endif; ?>

							<?php if ( esc_url( get_theme_mod( 'tc_social_linkedin' ) ) ) : ?>
								<li><a target="_blank" href="<?php echo esc_url( get_theme_mod( 'tc_social_linkedin' ) ); ?>"><i class="fa fa-linkedin" aria-hidden="true"></i></a></li>
							<?php endif; ?>

							<?php if ( esc_url( get_theme_mod( 'tc_social_twitter' ) ) ) : ?>
								<li><a target="_blank" href="<?php echo esc_url( get_theme_mod( 'tc_social_twitter' ) ); ?>"><i class="fa fa-twitter" aria-hidden="true"></i></a></li>
							<?php endif; ?>

							<?php if ( esc_url( get_theme_mod( 'tc_social_google' ) ) ) : ?>
								<li><a target="_blank" href="<?php echo esc_url( get_theme_mod( 'tc_social_google' ) ); ?>"><i class="fa fa-google" aria-hidden="true"></i></a></li>
							<?php endif; ?>

							<?php if ( esc_url( get_theme_mod( 'tc_social_pinterest' ) ) ) : ?>
								<li><a target="_blank" href="<?php echo esc_url( get_theme_mod( 'tc_social_pinterest' ) ); ?>"><i class="fa fa-pinterest" aria-hidden="true"></i></a></li>
							<?php endif; ?>

							<?php if ( esc_url( get_theme_mod( 'tc_social_youtube' ) ) ) : ?>
								<li><a target="_blank" href="<?php echo esc_url( get_theme_mod( 'tc_social_youtube' ) ); ?>"><i class="fa fa-youtube-play" aria-hidden="true"></i></a></li>
							<?php endif; ?>

							<?php if ( esc_url( get_theme_mod( 'tc_social_instagram' ) ) ) : ?>
								<li><a target="_blank" href="<?php echo esc_url( get_theme_mod( 'tc_social_instagram' ) ); ?>"><i class="fa fa-instagram" aria-hidden="true"></i></a></li>
							<?php endif; ?>
						</ul>
					</div>
				</div>
			</div>
		</div> <!-- End Subheader -->
	<?php endif; ?>

		<!-- Begin Header -->
		<div class="header-wrapper">
			<header id="header" <?php interico_header_atts(); ?>>
				<div class="container">
					<div class="row">
						<div class="col-md-12">

							<!-- Logo begin -->
							<h1 id="logo">
								<a href="<?php echo esc_url( home_url( '/' ) ); ?>">

									<?php
									$interico_logo    = get_theme_mod( 'tc_logo_img', get_template_directory_uri() . '/img/logo-white.png' );
									$interico_logo_2x = get_theme_mod( 'tc_logo_img_2x', get_template_directory_uri() . '/img/logo-white2x.png' );

									if ( ! empty( $interico_logo ) ) : ?>
									
										<img src="<?php echo esc_url( $interico_logo ); ?>" srcset="<?php echo esc_url( $interico_logo ); ?><?php echo empty( $interico_logo_2x ) ? '' : ', ' . esc_url( $interico_logo_2x ) . ' 2x'; ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
									
									<?php else : ?>
										<?php esc_attr( bloginfo( 'name' ) ); ?>
									<?php endif; ?>

								</a>
							</h1> <!-- Logo end -->

							<!-- Responsive nav button begin -->
							<button type="button" id="menu-btn" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#mainmenu" aria-expanded="false">
								<span class="sr-only"><?php esc_html_e( 'Toggle navigation', 'interico' ); ?></span>
								<span class="icon-bar top-bar"></span>
								<span class="icon-bar middle-bar"></span>
								<span class="icon-bar bottom-bar"></span>
							</button> <!-- Responsive nav button end -->

							<!-- Main menu begin -->
							<nav>
								<?php wp_nav_menu(
									array(
										'theme_location' => 'primary',
										'menu_id'		 => 'mainmenu', 
										'menu_class'	 => 'collapse navbar-collapse',
										)
									); ?>
							</nav>  <!-- Main menu end -->

							<?php if ( has_nav_menu( 'secondary' ) && 'yes' === $subnav_hide_mobile ) : ?>
								<nav>
									<?php wp_nav_menu(
										array(
											'theme_location' => 'secondary',
											'menu_id'		 => 'nav-secondary-mobile', 
											'menu_class'	 => 'animated',
											)
										); ?>
								</nav>
							<?php endif; ?>
						</div>
					</div>
				</div>
			</header> <!-- End Header -->
		</div>