<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for parent theme Interico for publication on ThemeForest
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

add_action( 'tgmpa_register', 'interico_register_required_plugins' );

function interico_register_required_plugins() {
	/*
	 * Array of plugin arrays
	 */
	$plugins = array(

		array(
		    'name' => 'Envato Market',
		    'slug' => 'envato-market',
		    'source' => 'https://envato.github.io/wp-envato-market/dist/envato-market.zip',
		    'required' => false,
		),
		array(
		    'name' => 'Themicart Shortcodes',
		    'slug' => 'themicart-shortcodes',
		    // 'source' => 'https://github.com/Themicart/Themicart-Shortcodes/archive/master.zip',
		    'source' => 'https://themicart.com/theme-forest-img/assets/themicart-shortcodes.zip',
		    'required' => true,
		    'force_activation' => true,
		),
		array(
		    'name'               => esc_html__( 'Advanced Custom Fields Pro', 'interico' ),
		    'slug'               => 'advanced-custom-fields-pro',
		    'source'             => 'https://themicart.com/theme-forest-img/assets/advanced-custom-fields-pro.zip',
		    'required'           => true,
		    'version'            => '5.6.9',
		    'force_activation'   => true,
		    'force_deactivation' => true,
		    'external_url'       => 'http://www.advancedcustomfields.com/pro/'
		),
		array(
		    'name'          => 'WPBakery Page Builder',
		    'slug'          => 'js_composer',
		    'source'            => 'https://themicart.com/theme-forest-img/assets/js_composer.zip',
		    'required'          => false,
		    'version'           => '3.7',
		    'force_activation'  => false,
		    'force_deactivation'=> false,
		    'external_url'      => '',
		),
        array(
			'name'               => esc_html__( 'Portfolio Post Type', 'interico' ),
			'slug'               => 'portfolio-post-type',
			'required'           => false,
		),
		array(
			'name'               => esc_html__( 'Contact Form 7', 'interico' ),
			'slug'               => 'contact-form-7',
			'required'           => false,
		),
		array(
			'name'               => esc_html__( 'Breadcrumb NavXT', 'interico' ),
			'slug'               => 'breadcrumb-navxt',
			'required'           => false,
		),
		array(
			'name'               => esc_html__( 'WooCommerce - excelling eCommerce', 'interico' ),
			'slug'               => 'woocommerce',
			'required'           => false,
		),
        array(
            'name'               =>  esc_html__( 'WP Featherlight - A Simple jQuery Lightbox', 'interico' ),
            'slug'               => 'wp-featherlight',
            'required'           => false,
        ),
        array(
            'name'               =>  esc_html__( 'Customizer Export/Import', 'interico' ),
            'slug'               => 'customizer-export-import',
            'required'           => false,
        ),
        array(
            'name'               =>  esc_html__( 'Customizer Reset', 'interico' ),
            'slug'               => 'customizer-reset-by-wpzoom',
            'required'           => false,
        ),
	);

	$config = array(
		'id'           => 'interico',             // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}

?>