<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Team_Member extends WP_Widget {

	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the name and description
	/*--------------------------------------------------*/

	public function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Team Member', 'interico' ), // Name
			array(
				'description' => esc_html__( 'Display Team Member', 'interico' ) // Description
			)
		);

		add_action( 'admin_enqueue_scripts', array( $this, 'member_upload_assets' ) );
		
	}

	public function member_upload_assets()
	{
		wp_enqueue_script('media-upload');
		wp_enqueue_script('thickbox');
		wp_enqueue_script('mfc-media-upload', get_template_directory_uri() . '/inc/widgets/member-media-upload.js', array( 'jquery' )) ;
		wp_enqueue_style('thickbox');
	}

	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/

	public function widget( $args, $instance ) {

		if ( isset( $instance['member_link'] ) ) {
			$member_link = $instance['member_link'];
		}

		if ( isset( $instance['member_title'] ) ) {
			$member_title = $instance['member_title'];
		}

		if ( isset( $instance['member_position'] ) ) {
			$member_position = $instance['member_position'];
		}

		if ( isset( $instance['member_phone'] ) ) {
			$member_phone = $instance['member_phone'];
		}

		if ( isset( $instance['member_phone_label'] ) ) {
			$member_phone_label = $instance['member_phone_label'];
		} else {
			$member_phone_label = false;
		}

		if ( isset( $instance['image'] ) ) {
			$image = $instance['image'];
		}

		if ( isset( $instance['member_bio'] ) ) {
			$member_bio = $instance['member_bio'];
		}

		if ( isset( $instance['member_bio_label'] ) ) {
			$member_bio_label = $instance['member_bio_label'];
		} else {
			$member_bio_label = false;
		}

		if ( isset( $instance['member_icon_1'] ) ) {
			$member_icon_1 = $instance['member_icon_1'];
		} else {
			$member_icon_1 = false;
		}

		if ( isset( $instance['member_icon_link_1'] ) ) {
			$member_icon_link_1 = $instance['member_icon_link_1'];
		} else {
			$member_icon_link_1 = false;
		}

		if ( isset( $instance['member_icon_2'] ) ) {
			$member_icon_2 = $instance['member_icon_2'];
		} else {
			$member_icon_2 = false;
		}

		if ( isset( $instance['member_icon_link_2'] ) ) {
			$member_icon_link_2 = $instance['member_icon_link_2'];
		} else {
			$member_icon_link_2 = false;
		}

		if ( isset( $instance['member_icon_3'] ) ) {
			$member_icon_3 = $instance['member_icon_3'];
		} else {
			$member_icon_3 = false;
		}

		if ( isset( $instance['member_icon_link_3'] ) ) {
			$member_icon_link_3 = $instance['member_icon_link_3'];
		} else {
			$member_icon_link_3 = false;
		}

		if ( isset( $instance['member_icon_4'] ) ) {
			$member_icon_4 = $instance['member_icon_4'];
		} else {
			$member_icon_4 = false;
		}

		if ( isset( $instance['member_icon_link_4'] ) ) {
			$member_icon_link_4 = $instance['member_icon_link_4'];
		} else {
			$member_icon_link_4 = false;
		}

		if ( isset( $instance['team_member_style'] ) ) {
			$team_member_style = $instance['team_member_style'];
		} else {
			$team_member_style = 'light';
		}


		echo $args['before_widget'];
		?>

		<!-- Begin team member -->
		<div class="team-member <?php echo esc_attr( $team_member_style ); ?>">
			<?php if( esc_url( $member_link ) ) : ?>
				<a href="<?php echo esc_url( $member_link ); ?>">
			<?php endif; ?>
				<div class="content-box">
					<?php if ( esc_url( $instance['image'] ) ) : ?>
						<div class="image-container">
							<div class="member-details">
								<?php if ( $member_phone ): ?>
									<hr>
									<?php if ( esc_attr( $member_phone_label ) ): ?>
										<span class="small"><?php echo esc_attr( $member_phone_label ); ?></span><br>
									<?php endif; ?>
									<span class="member-info"><?php echo esc_attr( $member_phone ); ?></span>
									<hr>
								<?php endif; ?>
								<?php if( esc_attr( $member_bio ) ) : ?>
									<?php if ( esc_attr ($member_bio_label) ): ?>
										<span class="small"><?php echo esc_attr($member_bio_label); ?></span><br>
									<?php endif; ?>
									<span class="member-info"><?php echo esc_attr( $member_bio ); ?></span>
									<hr>
								<?php endif; ?>
								<?php if ( esc_attr( $member_icon_1 ) || esc_attr( $member_icon_2 ) || esc_attr( $member_icon_3 ) || esc_attr( $member_icon_4 ) ) : ?>
								<ul class="social">
									<?php if ( esc_attr( $member_icon_1 ) ) : ?>
										<li><a target="_blank" href="<?php echo esc_url( $member_icon_link_1 ); ?>"><i class="fa <?php echo esc_attr( $member_icon_1 ); ?>" aria-hidden="true"></i></a></li>
									<?php endif; ?>

									<?php if ( esc_attr( $member_icon_2 ) ) : ?>
										<li><a target="_blank" href="<?php echo esc_url( $member_icon_link_2 ); ?>"><i class="fa <?php echo esc_attr( $member_icon_2 ); ?>" aria-hidden="true"></i></a></li>
									<?php endif; ?>

									<?php if ( esc_attr( $member_icon_3 ) ) : ?>
										<li><a target="_blank" href="<?php echo esc_url( $member_icon_link_3 ); ?>"><i class="fa <?php echo esc_attr( $member_icon_3 ); ?>" aria-hidden="true"></i></a></li>
									<?php endif; ?>

									<?php if ( esc_attr( $member_icon_4 ) ) : ?>
										<li><a target="_blank" href="<?php echo esc_url( $member_icon_link_4 ); ?>"><i class="fa <?php echo esc_attr( $member_icon_4 ); ?>" aria-hidden="true"></i></a></li>
									<?php endif; ?>
								</ul>
								<?php endif; ?>
							</div>
							<div class="side-overlay"></div>
							<?php if( esc_attr( $member_position ) ) : ?>
								<div class="vertical-number-box">
									<span class="vertical-number"><?php echo esc_attr( $member_position ); ?></span>
								</div>
							<?php endif; ?>
							<img src="<?php echo esc_url( $instance['image'] ) ?>" alt="<?php echo esc_attr( $member_title ); ?>">
						</div>
					<?php endif; ?>
					<div class="content-box-info">
						<h4><?php echo esc_attr( $member_title ); ?></h4>
					</div>
				</div>
			<?php if( esc_url( $member_link ) ) : ?>
				</a>
			<?php endif; ?>
		</div>
		<!-- End team member -->

		<?php
		echo $args['after_widget'];
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/
	
	public function update( $new_instance, $old_instance ) {
		$instance = array();

		$instance['member_link']     = sanitize_text_field( $new_instance['member_link'] );
		$instance['member_title']    = wp_kses_post( $new_instance['member_title'] );
		$instance['member_position'] = wp_kses_post( $new_instance['member_position'] );
		$instance['member_bio']      = wp_kses_post( $new_instance['member_bio'] );
		$instance['member_bio_label']      = wp_kses_post( $new_instance['member_bio_label'] );
		$instance['member_phone']    = wp_kses_post( $new_instance['member_phone'] );
		$instance['member_phone_label']    = wp_kses_post( $new_instance['member_phone_label'] );
		$instance['image']    		 = wp_kses_post( $new_instance['image'] );
		$instance['member_icon_1'] = wp_kses_post( $new_instance['member_icon_1'] );
		$instance['member_icon_link_1'] = wp_kses_post( $new_instance['member_icon_link_1'] );
		$instance['member_icon_2'] = wp_kses_post( $new_instance['member_icon_2'] );
		$instance['member_icon_link_2'] = wp_kses_post( $new_instance['member_icon_link_2'] );
		$instance['member_icon_3'] = wp_kses_post( $new_instance['member_icon_3'] );
		$instance['member_icon_link_3'] = wp_kses_post( $new_instance['member_icon_link_3'] );
		$instance['member_icon_4'] = wp_kses_post( $new_instance['member_icon_4'] );
		$instance['member_icon_link_4'] = wp_kses_post( $new_instance['member_icon_link_4'] );
		$instance['team_member_style'] = wp_kses_post( $new_instance['team_member_style'] );
		
		return $instance;
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	public function form( $instance ) {
		$member_link     = empty( $instance['member_link'] ) ? '' : $instance['member_link'];
		$member_title    = empty( $instance['member_title'] ) ? '' : $instance['member_title'];
		$member_bio      = empty( $instance['member_bio'] ) ? '' : $instance['member_bio'];
		$member_bio_label      = empty( $instance['member_bio_label'] ) ? '' : $instance['member_bio_label'];
		$member_position = empty( $instance['member_position'] ) ? '' : $instance['member_position'];
		$member_phone    = empty( $instance['member_phone'] ) ? '' : $instance['member_phone'];
		$member_phone_label    = empty( $instance['member_phone_label'] ) ? '' : $instance['member_phone_label'];
		$image 			 = empty( $instance['image'] ) ? '' : $instance['image'];
		$member_icon_1   = empty( $instance['member_icon_1'] ) ? '' : $instance['member_icon_1'];
		$member_icon_link_1 = empty( $instance['member_icon_link_1'] ) ? '' : $instance['member_icon_link_1'];
		$member_icon_2   = empty( $instance['member_icon_2'] ) ? '' : $instance['member_icon_2'];
		$member_icon_link_2 = empty( $instance['member_icon_link_2'] ) ? '' : $instance['member_icon_link_2'];
		$member_icon_3   = empty( $instance['member_icon_3'] ) ? '' : $instance['member_icon_3'];
		$member_icon_link_3 = empty( $instance['member_icon_link_3'] ) ? '' : $instance['member_icon_link_3'];
		$member_icon_4   = empty( $instance['member_icon_4'] ) ? '' : $instance['member_icon_4'];
		$member_icon_link_4 = empty( $instance['member_icon_link_4'] ) ? '' : $instance['member_icon_link_4'];
		$team_member_style = empty( $instance['team_member_style'] ) ? '' : $instance['team_member_style'];

		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'team_member_style' ) ); ?>"><?php esc_html_e( 'Color Scheme', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'team_member_style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'team_member_style' ) ); ?>">
				<option value="default" <?php selected( $team_member_style, 'default' ); ?>><?php esc_html_e( 'Style 1: Light', 'interico' ); ?></option>
				<option value="dark" <?php selected( $team_member_style, 'dark' ); ?>><?php esc_html_e( 'Style 2: Dark', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_title' ) ); ?>"><?php esc_html_e( 'Heading', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_title' ) ); ?>" type="text" value="<?php echo esc_attr( $member_title ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_link' ) ); ?>"><?php esc_html_e( 'Link to bio page (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_link' ) ); ?>" type="text" value="<?php echo esc_url( $member_link ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_position' ) ); ?>"><?php esc_html_e( 'Position (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_position' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_position' ) ); ?>" type="text" value="<?php echo esc_attr( $member_position ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_phone_label' ) ); ?>"><?php esc_html_e( 'Contact Label #1 (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_phone_label' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_phone_label' ) ); ?>" type="text" value="<?php echo esc_attr( $member_phone_label ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_phone' ) ); ?>"><?php esc_html_e( 'Contact detail #1 (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_phone' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_phone' ) ); ?>" type="text" value="<?php echo esc_attr( $member_phone ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_bio_label' ) ); ?>"><?php esc_html_e( 'Contact Label #2 (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_bio_label' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_bio_label' ) ); ?>" type="text" value="<?php echo esc_attr( $member_bio_label ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_bio' ) ); ?>"><?php esc_html_e( 'Contact Detail #2 (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_bio' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_bio' ) ); ?>" type="text" value="<?php echo esc_attr( $member_bio ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_name( 'image' ) ); ?>"><?php esc_html_e( 'Image (url):', 'interico' ); ?></label>
			<input name="<?php echo esc_attr( $this->get_field_name( 'image' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'image' ) ); ?>" class="widefat" type="text" size="36"  value="<?php echo esc_url( $image ); ?>" />
			<input class="upload_image_button button button-primary" type="button" value="Select Image" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_icon_1' ) ); ?>"><?php esc_html_e( 'Social Icon 1 (FontAwesome. Example: fa-facebook)', 'interico' ); ?>:</label><br/><small><em><?php printf( esc_html__( 'See %s for all icon classes (example: lnr-home)', 'interico' ), '<a href="'. esc_url( 'https://linearicons.com/free' ) . '" target="_blank">Linearicons</a>' ); ?></em></small>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_icon_1' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_icon_1' ) ); ?>" type="text" value="<?php echo esc_attr( $member_icon_1 ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_icon_link_1' ) ); ?>"><?php esc_html_e( 'Social Icon 1 Link', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_icon_link_1' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_icon_link_1' ) ); ?>" type="text" value="<?php echo esc_attr( $member_icon_link_1 ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_icon_2' ) ); ?>"><?php esc_html_e( 'Social Icon 2 (FontAwesome)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_icon_2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_icon_2' ) ); ?>" type="text" value="<?php echo esc_attr( $member_icon_2 ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_icon_link_2' ) ); ?>"><?php esc_html_e( 'Social Icon 2 Link', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_icon_link_2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_icon_link_2' ) ); ?>" type="text" value="<?php echo esc_attr( $member_icon_link_2 ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_icon_3' ) ); ?>"><?php esc_html_e( 'Social Icon 3 (FontAwesome)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_icon_3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_icon_3' ) ); ?>" type="text" value="<?php echo esc_attr( $member_icon_3 ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_icon_link_3' ) ); ?>"><?php esc_html_e( 'Social Icon 3 Link', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_icon_link_3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_icon_link_3' ) ); ?>" type="text" value="<?php echo esc_attr( $member_icon_link_3 ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_icon_4' ) ); ?>"><?php esc_html_e( 'Social Icon 4 (FontAwesome)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_icon_4' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_icon_4' ) ); ?>" type="text" value="<?php echo esc_attr( $member_icon_4 ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'member_icon_link_4' ) ); ?>"><?php esc_html_e( 'Social Icon 4 Link', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'member_icon_link_4' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'member_icon_link_4' ) ); ?>" type="text" value="<?php echo esc_attr( $member_icon_link_4 ); ?>" />
		</p>


		
		<?php
	}
}
add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Team_Member" );' ) );
